aboutsummaryrefslogtreecommitdiffstats
path: root/dcae-analytics-model/src/main/java/org/openecomp/dcae/apod/analytics/model/domain/cef/MeasurementsForVfScalingFields.java
diff options
context:
space:
mode:
Diffstat (limited to 'dcae-analytics-model/src/main/java/org/openecomp/dcae/apod/analytics/model/domain/cef/MeasurementsForVfScalingFields.java')
-rw-r--r--dcae-analytics-model/src/main/java/org/openecomp/dcae/apod/analytics/model/domain/cef/MeasurementsForVfScalingFields.java48
1 files changed, 36 insertions, 12 deletions
diff --git a/dcae-analytics-model/src/main/java/org/openecomp/dcae/apod/analytics/model/domain/cef/MeasurementsForVfScalingFields.java b/dcae-analytics-model/src/main/java/org/openecomp/dcae/apod/analytics/model/domain/cef/MeasurementsForVfScalingFields.java
index a6bf113..e492f2d 100644
--- a/dcae-analytics-model/src/main/java/org/openecomp/dcae/apod/analytics/model/domain/cef/MeasurementsForVfScalingFields.java
+++ b/dcae-analytics-model/src/main/java/org/openecomp/dcae/apod/analytics/model/domain/cef/MeasurementsForVfScalingFields.java
@@ -1,21 +1,21 @@
/*
- * ===============================LICENSE_START======================================
- * dcae-analytics
+ * ============LICENSE_START=========================================================
+ * dcae-analytics
* ================================================================================
- * Copyright © 2017 AT&T Intellectual Property. All rights reserved.
+ * Copyright © 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * You may obtain a copy of the License at
*
- * http://www.apache.org/licenses/LICENSE-2.0
+ * http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============================LICENSE_END===========================================
+ * ============LICENSE_END=========================================================
*/
package org.openecomp.dcae.apod.analytics.model.domain.cef;
@@ -28,16 +28,32 @@ import java.util.List;
/**
* Common Event Format - MeasurementsForVfScaling fields
* <p>
- * @author Rajiv Singla . Creation Date: 10/17/2016.
+ * @author Rajiv Singla. Creation Date: 08/15/2017.
*/
@Data
@EqualsAndHashCode(callSuper = true)
public class MeasurementsForVfScalingFields extends BaseCEFModel {
-
private static final long serialVersionUID = 1L;
/**
+ * Additional name-value-pair fields
+ *
+ * @param additionalFields New value for additional name-value-pair fields
+ * @return Additional name-value-pair fields
+ */
+ private List<Field> additionalFields;
+
+
+ /**
+ * Array of named name-value-pair arrays for additional Measurements
+ *
+ * @param additionalMeasurements New value for array of named name-value-pair arrays for additional Measurements
+ * @return Array of named name-value-pair arrays for additional Measurements
+ */
+ private List<NamedArrayOfFields> additionalMeasurements;
+
+ /**
* Interval over which measurements are being reported in seconds
*
* @param measurementInterval New value for measurement Interval
@@ -46,12 +62,20 @@ public class MeasurementsForVfScalingFields extends BaseCEFModel {
private Long measurementInterval;
/**
- * Virtual Network Card Usage Array
+ * Version of the measurementsForVfScaling block
+ *
+ * @param measurementsForVfScalingVersion New value for measurementsForVfScaling block
+ * @return Version of the measurementsForVfScaling block
+ */
+ private Float measurementsForVfScalingVersion;
+
+ /**
+ * Usage of an array of virtual network interface cards
*
* @param vNicUsageArray New value for Virtual Network Card Usage Array
* @return Virtual Network Card Usage Array
*/
- private List<VNicUsageArray> vNicUsageArray;
+ private List<VNicPerformance> vNicPerformanceArray;
}
@@ -46,12 +62,20 @@ public class MeasurementsForVfScalingFields extends BaseCEFModel {
*
- * @param vNicUsageArray New value for Virtual Network Card Usage Array
- * @return Virtual Network Card Usage Array
+ * @param vNicPerformanceArray New value for Usage of an array of virtual network interface cards
+ * @return Usage of an array of virtual network interface cards
*/